@@ -1,3 +1,4 @@
+import collections
 from operator import add
 
 import pytest
@@ -324,15 +325,6 @@ def test_atop_chunks():
     assert_eq(y, np.ones((20, 10)))
 
 
-def test_atop_raises_on_incorrect_indices():
-    x = da.arange(5, chunks=3)
-    with pytest.raises(ValueError) as info:
-        da.atop(lambda x: x, 'ii', x, 'ii', dtype=int)
-
-    assert 'ii' in str(info.value)
-    assert '1' in str(info.value)
-
-
 def test_atop_numpy_arg():
     x = da.arange(10, chunks=(5,))
     y = np.arange(1000)
@@ -361,3 +353,63 @@ def test_svd():
     u, s, v = da.linalg.svd(y)
     z = y + u
     assert_eq(z, z)
+
+
+@pytest.mark.parametrize('tup', [
+    (1, 2),
+    collections.namedtuple('foo', ['a', 'b'])(1, 2),
+])
+def test_namedtuple(tup):
+    A = da.random.random((20, 20), chunks=(10, 10))
+
+    def f(data, x):
+        return data
+
+    B = da.atop(f, ("d1", "d2"),
+                A, ("d1", "d2"),
+                x=tup,
+                dtype=A.dtype)
+
+    assert_eq(A, B)
+
+
+def test_validate_top_inputs():
+    A = da.random.random((20, 20), chunks=(10, 10))
+
+    with pytest.raises(ValueError) as info:
+        da.atop(inc, 'jk', A, 'ij', dtype=A.dtype)
+
+    assert 'unknown dimension' in str(info.value).lower()
+    assert 'k' in str(info.value)
+    assert 'j' not in str(info.value)
+
+    with pytest.raises(ValueError) as info:
+        da.atop(inc, 'ii', A, 'ij', dtype=A.dtype)
+
+    assert 'repeated' in str(info.value).lower()
+    assert 'i' in str(info.value)
+
+
+def test_gh_4176():
+    def foo(A):
+        return A[None, ...]
+
+    A = da.ones(shape=(10, 20, 4), chunks=(2, 5, 4))
+
+    name = 'D'
+
+    dsk = da.core.top(
+        foo, name, ("nsrc", "ntime", "nbl", "npol"),
+        A.name, ("ntime", "nbl", "npol"),
+        new_axes={"nsrc": 1},
+        numblocks={a.name: a.numblocks for a in (A,)}
+    )
+
+    array_dsk = dask.sharedict.ShareDict()
+    array_dsk.update(dsk)
+    array_dsk.update(A.__dask_graph__())
+
+    chunks = ((1,),) + A.chunks
+
+    D = da.Array(array_dsk, name, chunks, dtype=A.dtype)
+    D.sum(axis=0).compute()
