@@ -18,7 +18,7 @@ def subs(task, substitution):
     """
     if isinstance(task, dict):
         return {k: subs(v, substitution) for k, v in task.items()}
-    if isinstance(task, (tuple, list, set)):
+    if type(task) in (tuple, list, set):
         return type(task)([subs(x, substitution) for x in task])
     try:
         return substitution[task]
@@ -455,6 +455,16 @@ def atop(func, out_ind, *args, **kwargs):
     adjust_chunks = kwargs.pop('adjust_chunks', None)
     new_axes = kwargs.get('new_axes', {})
 
+    # Input Validation
+    if len(set(out_ind)) != len(out_ind):
+        raise ValueError("Repeated elements not allowed in output index",
+                         [k for k, v in toolz.frequencies(out_ind).items() if v > 1])
+    new = (set(out_ind)
+           - {a for arg in args[1::2] if arg is not None for a in arg}
+           - set(new_axes or ()))
+    if new:
+        raise ValueError("Unknown dimension", new)
+
     from .core import Array, unify_chunks, normalize_arg
 
     if dtype is None:
@@ -591,7 +601,8 @@ def optimize_atop(full_graph, keys=()):
             deps = set(top_layers)
             while deps:  # we gather as many sub-layers as we can
                 dep = deps.pop()
-                if (isinstance(layers[dep], TOP) and
+                if (dep in layers and
+                        isinstance(layers[dep], TOP) and
                         not (dep != layer and dep in keep) and  # output layer
                         layers[dep].concatenate == layers[layer].concatenate):  # punt on mixed concatenate
                     top_layers.add(dep)
