@@ -476,6 +476,19 @@ def get_fs(protocol, storage_options=None):
                         "    pip install gcsfs")
         cls = _filesystems[protocol]
 
+    elif protocol in ['adl', 'adlfs']:
+
+        import_required('dask_adlfs',
+                        "Need to install `dask_adlfs` for Azure Datalake "
+                        "Storage support.\n"
+                        "First install azure-storage via pip or conda:\n"
+                        "    conda install -c conda-forge azure-storage\n"
+                        "    or\n"
+                        "    pip install azure-storage\n"
+                        "and then install `dask_adlfs` via pip:\n"
+                        "    pip install dask-adlfs")
+
+        cls = _filesystems[protocol]
     elif protocol == 'hdfs':
         cls = get_hdfs_driver(config.get("hdfs_driver", "auto"))
 
