@@ -668,6 +668,7 @@ def test_ordering(tmpdir, write_engine, read_engine):
 
 
 def test_read_parquet_custom_columns(tmpdir, engine):
+    import glob
     tmp = str(tmpdir)
     data = pd.DataFrame({'i32': np.arange(1000, dtype=np.int32),
                          'f': np.arange(1000, dtype=np.float64)})
@@ -681,6 +682,15 @@ def test_read_parquet_custom_columns(tmpdir, engine):
     assert_eq(df[['i32', 'f']], df2,
               check_index=False, check_divisions=should_check_divs(engine))
 
+    import glob
+    fns = glob.glob(os.path.join(tmp, '*.parquet'))
+    df2 = dd.read_parquet(fns,
+                          columns=['i32'],
+                          engine=engine).compute()
+    df2.sort_values('i32', inplace=True)
+    assert_eq(df[['i32']], df2,
+              check_index=False, check_divisions=False)
+
     df3 = dd.read_parquet(tmp,
                           columns=['f', 'i32'],
                           engine=engine,
