@@ -193,7 +193,7 @@ class RewriteRule(object):
 
     def __str__(self):
         return "RewriteRule({0}, {1}, {2})".format(self.lhs, self.rhs,
-                self.vars)
+                                                   self.vars)
 
     def __repr__(self):
         return str(self)
@@ -406,7 +406,7 @@ def _match(S, N):
             # Backtrack here
             (S, N, matches) = stack.pop()
             restore_state_flag = True
-        except:
+        except Exception:
             return
 
 
